<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <source>Themes or indent schemes not found.
Check installation.</source>
        <translation type="obsolete">Farb- oder Formatierungsvorlagen nicht gefunden.
Installation prüfen.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="132"/>
        <location filename="mainwindow.cpp" line="152"/>
        <source>Initialization error</source>
        <translation>Initialisierungsfehler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="133"/>
        <source>Could not read a colour theme: </source>
        <translation>Konnte dieses Farbschema nicht lesen: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="137"/>
        <source>light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="138"/>
        <source>dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="139"/>
        <source>B16 light</source>
        <translation>B16 Hell</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="140"/>
        <source>B16 dark</source>
        <translation>B16 Dunkel</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="153"/>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation>Syntaxdefinitionen nicht gefunden.
Installation prüfen.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="232"/>
        <source>Always at your service</source>
        <translation>Stets zu Diensten</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="266"/>
        <source>Select one or more files to open</source>
        <translation>Wähle eine oder mehrere Dateien zum Öffnen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="303"/>
        <source>Select destination directory</source>
        <translation>Wähle das Zielverzeichnis</translation>
    </message>
    <message>
        <source>Tags file error</source>
        <translation type="obsolete">Tags Dateifehler</translation>
    </message>
    <message>
        <source>Could not read tags information in &quot;%1&quot;</source>
        <translation type="obsolete">Konnte Tags-Informationen in %1 nicht lesen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="930"/>
        <location filename="mainwindow.cpp" line="961"/>
        <source>Output error</source>
        <translation>Ausgabefehler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="930"/>
        <source>Output directory does not exist!</source>
        <translation>Zielverzeichnis existert nicht!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="961"/>
        <source>You must define a style output file!</source>
        <translation>Sie müssen ein Stylesheet zur Ausgabe angeben!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="993"/>
        <source>Processing %1 (%2/%3)</source>
        <translation>Verarbeite %1 (%2/%3)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="999"/>
        <source>Language definition error</source>
        <translation>Fehler in Sprachdefinition</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1000"/>
        <source>Invalid regular expression in %1:
%2</source>
        <translation>Ungültiger regulärer Ausdruck in %1: %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1004"/>
        <source>Unknown syntax</source>
        <translation>Unbekannte Syntax</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1004"/>
        <source>Could not convert %1</source>
        <translation>Konnte %1 nicht konvertieren</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1007"/>
        <source>Lua error</source>
        <translation>Lua Fehler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1007"/>
        <source>Could not convert %1:
Lua Syntax error: %2</source>
        <translation>Konnte %1 nicht konvertieren:\nLua Syntaxfehler: %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1085"/>
        <source>Converted %1 files in %2 ms</source>
        <translation>%1 Dateien in %2 ms konvertiert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1208"/>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation>Konnte &quot;%1&quot; nicht konvertieren.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1208"/>
        <location filename="mainwindow.cpp" line="1330"/>
        <location filename="mainwindow.cpp" line="1355"/>
        <source>clipboard data</source>
        <translation>Daten der Zwischenablage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1275"/>
        <source>%1 options</source>
        <translation>%1-Optionen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1312"/>
        <location filename="mainwindow.cpp" line="1319"/>
        <source>(user script)</source>
        <translation>(Benutzerskript)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1329"/>
        <source>Preview (%1):</source>
        <translation>Vorschau (%1):</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1332"/>
        <source>Current syntax: %1 %2</source>
        <translation>Aktuelle Syntax: %1 %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1333"/>
        <source>Current theme: %1 %2</source>
        <translation>Farbschema: %1 %2</translation>
    </message>
    <message>
        <source>Current syntax: %1</source>
        <translation type="vanished">Aktuelle Syntax: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1355"/>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation>Vorschau von &quot;%1&quot; nicht möglich.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1595"/>
        <source>Some plug-in effects may not be visible in the preview.</source>
        <translation>Einige Plug-In Effekte könnten in der Vorschau nicht dargestellt werden.</translation>
    </message>
    <message>
        <source>Choose a ctags file</source>
        <translation type="obsolete">Wählen Sie eine ctags Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1390"/>
        <location filename="mainwindow.cpp" line="1394"/>
        <location filename="mainwindow.cpp" line="1398"/>
        <location filename="mainwindow.cpp" line="1403"/>
        <source>Choose a style include file</source>
        <translation>Wählen Sie ein Eingabe-Stylesheet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1408"/>
        <source>About providing translations</source>
        <translation>Übersetzungen bereitstellen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1409"/>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation>Diese GUI wurde mit dem Qt Toolkit entwickelt, daher werden Übersetzungsdateien mit den Werkzeugen Qt Linguist und lrelease erstellt.
Die highlight.ts Datei für Linguist befindet sich im src/gui-qt Unterverzeichnis.
Die von lrelease ausgegebene qm-Datei wird in gui-files/l10n gespeichert.

Bitte senden Sie eine Nachricht an as (at) andre-simon (dot) de, wenn Sie Probleme bei der Übersetzung haben oder wenn Sie eine Übersetzung fertiggestellt bzw. aktualisiert haben.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1467"/>
        <source>Select one or more plug-ins</source>
        <translation>Wähle ein Plug-in</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1478"/>
        <source>Select one or more syntax or theme scripts</source>
        <translation>Wähle ein oder mehrere Syntax- oder Themeskripte aus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1538"/>
        <source>Choose a plug-in input file</source>
        <translation>Wähle eine Eingabedatei für Plug-Ins aus</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Choose the source code files you want to convert.</source>
        <translation>Wähle  Sourcecode-Dateien zur Konvertierung aus.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <source>Choose input files</source>
        <translation>Dateien wählen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="212"/>
        <source>List of input files.</source>
        <translation>Liste der Eingabedateien.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Remove the selected input files.</source>
        <translation>Lösche die markierten Dateien aus der Eingabeliste.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.ui" line="582"/>
        <location filename="mainwindow.ui" line="718"/>
        <source>Clear selection</source>
        <translation>Auswahl entfernen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Remove all input files.</source>
        <translation>Lösche  die Eingabeliste.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="249"/>
        <location filename="mainwindow.ui" line="592"/>
        <location filename="mainwindow.ui" line="728"/>
        <source>Clear all</source>
        <translation>Alle entfernen</translation>
    </message>
    <message>
        <source>Output destination</source>
        <translation type="obsolete">Zielverzeichnis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="288"/>
        <source>Output directory</source>
        <translation>Zielverzeichnis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Select the output directory.</source>
        <translation>Wähle das Ausgabeverzeichnis.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="310"/>
        <location filename="mainwindow.ui" line="669"/>
        <location filename="mainwindow.ui" line="1318"/>
        <location filename="mainwindow.ui" line="1587"/>
        <location filename="mainwindow.ui" line="1695"/>
        <location filename="mainwindow.ui" line="1990"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Save output in the input file directories.</source>
        <translation>Speichere Ausgabe in den Verzeichnissen der Eingabedateien.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Write to source directories</source>
        <translation>In Quellverzeichnisse schreiben</translation>
    </message>
    <message>
        <source>Output options</source>
        <translation type="obsolete">Ausgabeoptionen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Output for&amp;mat:</source>
        <oldsource>Output format:</oldsource>
        <translation>Ausgabeformat:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="830"/>
        <source>Choose an output format.</source>
        <translation>Wähle ein Ausgabeformat.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="834"/>
        <source>HTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="839"/>
        <source>XHTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="844"/>
        <source>LaTeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="849"/>
        <source>TeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="854"/>
        <source>RTF</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="859"/>
        <source>ODT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="864"/>
        <source>SVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="888"/>
        <source>Add line numbers to the output.</source>
        <translation>Füge Zeilennummern zur Ausgabe hinzu.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="891"/>
        <source>Add line numbers</source>
        <translation>Zeilennummerierung</translation>
    </message>
    <message>
        <source>Set line numbering start</source>
        <translation type="vanished">Lege den Beginn der Nummerierung fest</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="930"/>
        <source>Select the line number width.</source>
        <translation>Wähle die Stellenanzahl der Nummerierung.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="951"/>
        <source>Fill leading space of line numbers with zeroes.</source>
        <translation>Fülle Zeilennummerierung mit Nullen auf.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="954"/>
        <source>Pad with zeroes</source>
        <translation>Zeige führende Nullen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="967"/>
        <source>Generate output without document header and footer.</source>
        <translation>Erzeuge Ausgabe ohne Dokumentenkopf und -fußteil.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="970"/>
        <source>Omit header and footer</source>
        <translation>Kopf- und Fußteil auslassen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <source>Output any plug-in text injections even if document header and footer is omitted.</source>
        <translation>Gib Textausgaben der Plug-Ins aus auch wenn Kopf- und Fußteil der Dokumente weggelassen werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="980"/>
        <source>Keep Plug-In injections</source>
        <translation>Behalte Plug-In Ausgaben</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="987"/>
        <source>Test if input data is not binary.
Removes Unicode BOM mark.</source>
        <translation>Stellt sicher, daß die Eingabe nicht binär ist.
Entfernt den Unicode BOM.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="991"/>
        <source>Validate input data</source>
        <translation>Prüfe Eingabedaten</translation>
    </message>
    <message>
        <source>Set the output file ancoding.</source>
        <translation type="vanished">Setzt das Encoding.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1828"/>
        <source>I&amp;mage width:</source>
        <translation>Bild&amp;breite:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1876"/>
        <source>Height:</source>
        <oldsource>Image height:</oldsource>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2134"/>
        <source>Reformat and indent your code.
This feature is enabled for C, C++, C# and Java code.</source>
        <translation>Formatiere den Eingabecode.
Diese Funktion kann auf C, C++, C# und Java-Code angewandt werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2462"/>
        <source>&amp;Plug-Ins</source>
        <translation>&amp;Plug-Ins</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation type="obsolete">Encoding:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Select or define the encoding.
The result has to match the input file encoding.</source>
        <translation>Wähle oder definiere das Ausgabe-Encoding.
Das Encoding muss mit den Eingabedateien übereinstimmen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1031"/>
        <source>ISO-8859-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1036"/>
        <source>ISO-8859-2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1041"/>
        <source>ISO-8859-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1046"/>
        <source>ISO-8859-4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1051"/>
        <source>ISO-8859-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1056"/>
        <source>ISO-8859-6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1061"/>
        <source>ISO-8859-7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1066"/>
        <source>ISO-8859-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1071"/>
        <source>ISO-8859-9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1076"/>
        <source>ISO-8859-10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1081"/>
        <source>ISO-8859-11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1086"/>
        <source>ISO-8859-12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1091"/>
        <source>ISO-8859-13</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1096"/>
        <source>ISO-8859-14</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>ISO-8859-15</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1106"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1130"/>
        <source>Output specific</source>
        <translation>Format-Optionen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1427"/>
        <source>Add HTML MIME Type when copying code to the clipboard</source>
        <translation>Füge HTML MIME-Type hinzu wenn Code in die Zwischenablage kopiert wird</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1430"/>
        <source>Copy with MIME type</source>
        <translation>Kopiere mit MIME-Type</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1468"/>
        <source>Adapt output for the Babel package</source>
        <translation>Passe die Ausgabe für das Babel-Paket an</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1478"/>
        <source>Adapt output for the Beamer package</source>
        <translation>Passe die Ausgabe für das Beamer-Paket an</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1481"/>
        <source>Add Beamer compatibility</source>
        <translation>Beamer Kompatibilität</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1732"/>
        <source>Set page color attribute to background color.</source>
        <translation>Setze die Hintergrundfarbe als Seitenfarbe.</translation>
    </message>
    <message>
        <source>HTML options</source>
        <translation type="obsolete">HTML Optionen</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="obsolete">Stylesheets</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1179"/>
        <location filename="mainwindow.ui" line="1505"/>
        <location filename="mainwindow.ui" line="1613"/>
        <location filename="mainwindow.ui" line="1908"/>
        <source>Include the style information in each output file.</source>
        <translation>Füge die Stylesheets in jede Ausgabedatei ein.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <location filename="mainwindow.ui" line="1911"/>
        <source>Embed style (CSS)</source>
        <translation>CSS einbetten</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1195"/>
        <source>Add CSS information to each tag (do not use CSS class definitions).</source>
        <translation>Füge Stylesheets in jeden Tag ein (benutze keine CSS Klassen).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1198"/>
        <source>Inline CSS</source>
        <translation></translation>
    </message>
    <message>
        <source>Style file:</source>
        <translation type="obsolete">Stylesheet-Datei:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1258"/>
        <location filename="mainwindow.ui" line="1641"/>
        <location filename="mainwindow.ui" line="1936"/>
        <source>Name of the referenced style file.</source>
        <translation>Name des  referenzierten Stylesheets.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1261"/>
        <location filename="mainwindow.ui" line="1939"/>
        <source>highlight.css</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include file:</source>
        <translation type="obsolete">Eingabe-Stylesheet:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1302"/>
        <location filename="mainwindow.ui" line="1974"/>
        <source>Path of the CSS include file.</source>
        <translation>Pfad zur CSS-Datei, die ins Stylesheet eingefügt werden soll.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1315"/>
        <source>Select a CSS include file.</source>
        <translation>Wähle eine Stylesheet-Eingabedatei.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1212"/>
        <source>CSS class prefix:</source>
        <translation>CSS Präfix:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1225"/>
        <source>Add a CSS class name prefix to avoid namespace clashes.</source>
        <translation>Definiere einen CSS-Klassennamen, um Kollisionen mit anderen Stylesheets zu vermeiden.</translation>
    </message>
    <message>
        <source>Tags and index files</source>
        <translation type="obsolete">Tags- und Indexdateien</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1400"/>
        <source>Generate an index file with hyperlinks to all outputted files.</source>
        <translation>Erzeuge eine Indexdatei mit Links zu allen Ausgabedateien.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1403"/>
        <source>Generate index file</source>
        <translation>Indexdatei erzeugen</translation>
    </message>
    <message>
        <source>Read a ctags file and add the included metainformation as tooltips.
See ctags.sf.net for details.</source>
        <translation type="obsolete">Lese eine ctags-Datei und füge die Metainformationen als Tooltips hinzu.
Siehe ctags.sf.net um mehr darüber zu erfahren.</translation>
    </message>
    <message>
        <source>Ctags file:</source>
        <translation type="obsolete">Ctags Datei:</translation>
    </message>
    <message>
        <source>Path of the ctags file.</source>
        <translation type="obsolete">Pfad der ctags-Datei.</translation>
    </message>
    <message>
        <source>Choose a ctags file.</source>
        <translation type="obsolete">Wähle eine ctags Datei.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1344"/>
        <source>Misc</source>
        <translation>Verschiedenes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1363"/>
        <source>Add an achor to each line.</source>
        <translation>Füge Anker zu jeder Zeile hinzu.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1366"/>
        <source>Add line anchors</source>
        <translation>Anker einfügen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1373"/>
        <source>Add the filename as prefix to the anchors.</source>
        <translation>Füge Dateinamen als Präfix zum Anker hinzu.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1376"/>
        <source>Include file name in anchor</source>
        <translation>Dateiname im Anker</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1383"/>
        <source>Output the lines within an ordered list.</source>
        <translation>Gib die Zeilen als sortierte Liste aus.</translation>
    </message>
    <message>
        <source>Ordered list</source>
        <translation type="obsolete">Sortierte Liste</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1410"/>
        <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
        <translation>Schließe die Ausgabe in  &amp;lt;pre&amp;gt;-Tags ein, wenn die Option &quot;Kopf- und Fußteil auslassen&quot; gewählt ist.</translation>
    </message>
    <message>
        <source>Enclose in &lt;pre&gt;</source>
        <translation type="obsolete">Schließe in &amp;lt;pre&amp;gt; ein</translation>
    </message>
    <message>
        <source>LaTeX options</source>
        <translation type="obsolete">LaTeX Optionen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1458"/>
        <source>Replace quotes by dq sequences.</source>
        <translation>Ersetze Anführungszeichen mit \dq-Sequenzen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1461"/>
        <source>Escape quotes</source>
        <translation>Ersetze Anführungszeichen</translation>
    </message>
    <message>
        <source>Make output Babel compatible.</source>
        <translation type="vanished">Erzeuge Code, der mit Babel verträglich ist.</translation>
    </message>
    <message>
        <source>Babel compatibility</source>
        <translation type="obsolete">Babel Kompatibilität</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1488"/>
        <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
        <translation>Ersetze Standard-Darstellung verschiedener Symbole (Klammern, Tilde) durch schönere Definitionen.</translation>
    </message>
    <message>
        <source>Pretty symbols</source>
        <translation type="obsolete">Schönere Symbole</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1508"/>
        <source>Embed style (defs)</source>
        <translation>Stylesheet einbetten</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1533"/>
        <source>Name of the referenced  style file.</source>
        <translation>Name des  referenzierten Stylesheets.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1536"/>
        <location filename="mainwindow.ui" line="1644"/>
        <source>highlight.sty</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include:</source>
        <translation type="obsolete">Eingabe-Stylesheet:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1013"/>
        <source>Set encoding:</source>
        <translation>Encoding:</translation>
    </message>
    <message>
        <source>Read ctags file:</source>
        <translation type="obsolete">Lese ctags-Datei:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1386"/>
        <source>Output as ordered list</source>
        <translation>Sortierte Liste</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1413"/>
        <source>Enclose in pre tags</source>
        <translation>Schließe in pre-Tags  ein</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1471"/>
        <source>Add Babel compatibility</source>
        <translation>Babel Kompatibilität</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1491"/>
        <source>Add pretty symbols</source>
        <translation>Symbole anpassen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1239"/>
        <location filename="mainwindow.ui" line="1517"/>
        <location filename="mainwindow.ui" line="1625"/>
        <location filename="mainwindow.ui" line="1920"/>
        <source>Stylesheet file:</source>
        <translation>Stylesheet-Datei:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="273"/>
        <source>Output destination:</source>
        <translation>Zielverzeichnis:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="329"/>
        <source>Browse output directory</source>
        <translation>Öffne das Ausgabeverzeichnis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="481"/>
        <source>Paste code from clipboard and copy the output back in one step</source>
        <translation>Füge Text aus der Zwischenablage ein und kopiere die formatierte Ausgabe in einem Schritt wieder zurück</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="487"/>
        <source>Paste, Convert and Copy</source>
        <translation>Einfügen, konvertieren und kopieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <source>Only output the selected lines of the preview.</source>
        <translation>Gib nur die in der Vorschau markierten Zeilen aus.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="516"/>
        <source>Output selected lines only</source>
        <translation>Nur selektierte Zeilen ausgeben</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="683"/>
        <source>Scripts</source>
        <translation>Skripte</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="689"/>
        <source>Choose a custom syntax or theme script.</source>
        <translation>Wähle ein eigenes Syntax- oder Themeskript.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="692"/>
        <source>Add custom script to pool</source>
        <translation>Füge Skript zur Sammlung hinzu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="706"/>
        <source>You can check one file of each type (syntax and theme) to override the default behaviour. If checked, the scripts will be watched for changes.</source>
        <oldsource>You can check one file of each type (syntax and theme) to override the default behaviour.</oldsource>
        <translation>Du kannst eine Datei jeden Typs wählen (Syntax bzw. Theme), um die Ausgabe anzupassen. Bei Aktivierung wird das Skript auf Änderungen überwacht.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="715"/>
        <source>Remove the selected scripts.</source>
        <translation>Entferne ausgewählte Skripte aus der Liste.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="725"/>
        <source>Remove all scripts.</source>
        <translation>Entferne alle Skripte aus der Liste.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="743"/>
        <source>Shows decription of a selected script.</source>
        <translation>Zeigt die Beschreibung des gewählten Skripts an.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="746"/>
        <source>Script description</source>
        <translation>Skriptbeschreibung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="911"/>
        <source>Set line numbering start.</source>
        <translation>Lege den Beginn der Nummerierung fest.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="998"/>
        <source>Generate output without version information comment.</source>
        <translation>Erzeuge Ausgabe ohne Versionskommentar.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1001"/>
        <source>Omit version info comment</source>
        <translation>Versionskommentar auslassen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Set the output file encoding.</source>
        <translation>Das Ausgabe-Encoding bestimmen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1272"/>
        <location filename="mainwindow.ui" line="1547"/>
        <location filename="mainwindow.ui" line="1655"/>
        <location filename="mainwindow.ui" line="1950"/>
        <source>Stylesheet include file:</source>
        <translation>Eingabe-Stylesheet:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1356"/>
        <source>Line numbering options:</source>
        <translation>Optionen der Zeilennummerierung:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <source>Highlight</source>
        <translation>Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="174"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <source>Paste clipboard content into the preview window.</source>
        <translation>Füge Inhalt der Zwischenablage in die Vorschau ein.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="438"/>
        <source>Paste from clipboard (%1)</source>
        <oldsource>Paste from clipboard</oldsource>
        <translation>Aus Zwischenablage einfügen (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="455"/>
        <source>Copy highlighted code into the clipboard.</source>
        <translation>Kopiere formatierte Ausgabe in die Zwischenablage.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Copy preview to clipboard (%1)</source>
        <oldsource>Copy preview to clipboard</oldsource>
        <translation>In Zwischenablage kopieren (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <source>Select syntax:</source>
        <translation>Syntax wählen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="426"/>
        <source>Select the correct syntax of the code snippet.</source>
        <translation>Wähle die zum Text passende Syntax.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="541"/>
        <source>Plug-ins</source>
        <translation>Plug-Ins</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="550"/>
        <source>Add plug-in to pool</source>
        <translation>Füge Plug-In zur Sammlung hinzu</translation>
    </message>
    <message>
        <source>List of plug-ins.</source>
        <translation type="obsolete">Sammlung von Plug-Ins.</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Remove the selected plug-ins.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Entferne die selektierten Plug-Ins</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Remove all plug-ins.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Entferne alle Plug-Ins</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Use the selected plugin.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Bneutze das ausgewählte Plug-In</translation>
    </message>
    <message>
        <source>Enable selected plug-in script</source>
        <translation type="obsolete">Aktiviere das selektierte Plug-In Skript</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="869"/>
        <source>BBCode</source>
        <translation>BBCode</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1171"/>
        <source>Stylesheets</source>
        <translation>Stylesheets</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation type="vanished">Eingabedatei:</translation>
    </message>
    <message>
        <source>Index/ctags</source>
        <translation type="obsolete">Index/ctags</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1571"/>
        <location filename="mainwindow.ui" line="1679"/>
        <source>Path of the style include file.</source>
        <translation>Pfad zur sty-Datei, die ins Stylesheet eingefügt werden soll.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1584"/>
        <location filename="mainwindow.ui" line="1692"/>
        <location filename="mainwindow.ui" line="1987"/>
        <source>Select a style include file.</source>
        <translation>Wähle eine Stylesheet-Eingabedatei.</translation>
    </message>
    <message>
        <source>TeX options</source>
        <translation type="obsolete">TeX Optionen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1616"/>
        <source>Embed style (macros)</source>
        <translation>Stylesheet einbetten</translation>
    </message>
    <message>
        <source>RTF options</source>
        <translation type="obsolete">RTF Optionen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1721"/>
        <source>Add character stylesheets with formatting information.
You can select the stylesheets in your word processor to reformat additional text.</source>
        <translation>Füge Zeichenvorlagen mit Formatierungsinformationen hinzu.
Diese können in der Textverarbeitung gewählt werden, um zusätzlichen Text zu formatieren.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1725"/>
        <source>Add character styles</source>
        <translation>Zeichenvorlagen</translation>
    </message>
    <message>
        <source>Set page color attribute to background color</source>
        <translation type="vanished">Setze die Hintergrundfarbe als Seitenfarbe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1735"/>
        <source>Set page color</source>
        <translation>Seitenfarbe setzen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1744"/>
        <source>Page size:</source>
        <translation>Papierformat:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1757"/>
        <source>Select a page size.</source>
        <translation>Wähle eine Seitengröße aus.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1764"/>
        <source>A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1769"/>
        <source>A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1774"/>
        <source>A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1779"/>
        <source>B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1784"/>
        <source>B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1789"/>
        <source>B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1794"/>
        <source>Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1799"/>
        <source>Legal</source>
        <translation></translation>
    </message>
    <message>
        <source>SVG options</source>
        <translation type="obsolete">SVG Optionen</translation>
    </message>
    <message>
        <source>Image size:</source>
        <translation type="vanished">Bildgröße:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="vanished">Breite:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1856"/>
        <source>Enter the SVG width (may contain units).</source>
        <translation>Gib die Bildbreite ein (kann Größeneinheiten enthalten).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1892"/>
        <source>Enter the SVG height (may contain units).</source>
        <translation>Gib die Bildhöhe ein (kann Größeneinheiten enthalten).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2016"/>
        <source>No options defined.</source>
        <translation>Keine Optionen vorhanden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2041"/>
        <source>Formatting</source>
        <translation>Formatierung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2070"/>
        <source>Color theme:</source>
        <translation>Farbschema:</translation>
    </message>
    <message>
        <source>Toggle classic theme or Base16 theme selection.</source>
        <translation type="vanished">Wechsle zwischen den klassischen und den Base16 Themes.</translation>
    </message>
    <message>
        <source>Base16</source>
        <translation type="vanished">Base16</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2117"/>
        <source>Select a colour theme.</source>
        <translation>Wähle ein Farbschema.</translation>
    </message>
    <message>
        <source>Reformat and indent your code.
This feature is enabled tor C, C++, C# and Java code.</source>
        <translation type="vanished">Formatiere den Eingabecode.
Diese Funktion kann auf C, C++, C# und Java-Code angewandt werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2138"/>
        <source>Reformat:</source>
        <translation>Formatieren:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2157"/>
        <source>Choose a formatting scheme.</source>
        <translation>Wähle ein Formatierungs-Schema.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2171"/>
        <source>Change the keyword case.</source>
        <translation>Ändere die Groß- und Kleinschreibung, wenn die Eingabesyntax nicht case-sensitive ist.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2174"/>
        <source>Keyword case:</source>
        <translation>Schlüsselwort Case:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2193"/>
        <source>Select a keyword case.</source>
        <translation>Wähle einen Typ der Groß- und Kleinschreibung.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2200"/>
        <source>UPPER</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2205"/>
        <source>lower</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2210"/>
        <source>Capitalize</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2228"/>
        <source>Tab width:</source>
        <translation>Tabulatorbreite:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2244"/>
        <source>Enter the number of spaces which replace a tab.
Set the width to 0 to keep tabs.</source>
        <translation>Gib die Anzahl der Leerzeichen an, die ein Tab ersetzen.
Setze die Anzahl auf Null, um Tabs auszugeben.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2259"/>
        <source>Enable line wrapping.</source>
        <translation>Aktiviere den automatischen Zeilenumbruch.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2262"/>
        <source>Line wrapping</source>
        <translation>Zeilenumbruch</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2275"/>
        <source>Enter the maximum line length.</source>
        <translation>Gib die maximale Zeilenlänge ein.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2294"/>
        <source>Indent statements and function parameters after wrapping.</source>
        <translation>Rücke Kommandos und Funktionsparameter nach dem Umbruch ein.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2297"/>
        <source>Intelligent wrapping</source>
        <translation>Intelligenter Umbruch</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2318"/>
        <source>Font na&amp;me:</source>
        <oldsource>Font name:</oldsource>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <source>Select or enter the font name.</source>
        <translation type="obsolete">Wähle oder gib die Schriftart an.</translation>
    </message>
    <message>
        <source>Font size:</source>
        <translation type="vanished">Schriftgröße:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2373"/>
        <source>Enter the font size.</source>
        <translation>Gib die Schriftgröße ein.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2446"/>
        <source>&amp;Visit andre-simon.de</source>
        <oldsource>Visit andre-simon.de</oldsource>
        <translation>&amp;Besuche andre-simon.de</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2457"/>
        <source>&amp;Dock floating panels</source>
        <translation>&amp;Schwebende Fenster andocken</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <source>Visit website</source>
        <translation type="obsolete">Website aufrufen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="383"/>
        <source>Start the conversion of your input files.</source>
        <translation>Starte die Konvertierung der Eingabedateien.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="386"/>
        <source>Convert files</source>
        <translation>Konvertieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="396"/>
        <source>Copy highlighted code of the seleted file into the clipboard.</source>
        <translation>Kopiere den Inhalt der ausgewählten Datei mit Highlighting in die Zwischenablage.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="399"/>
        <source>Copy file to clipboard</source>
        <translation>Datei in Zwischenablage</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="547"/>
        <source>Choose a plug-in script.</source>
        <translation>Wähle ein Plug-In Skript aus.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="561"/>
        <source>List of plug-ins. Toggle checkbox to enable the scripts. The preview window may not display all plug-in effects.</source>
        <oldsource>List of plug-ins. Toggle checkbox to enable the scripts.</oldsource>
        <translation>Liste der Plug-Ins. Klicke auf die Checkboxen um Skripte zu aktivieren. Die Vorschau zeigt möglicherweise nicht alle Effekte an.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="579"/>
        <source>Remove the selected plug-ins.</source>
        <translation>Entferne ausgewählte Plug-Ins aus der Liste.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="589"/>
        <source>Remove all plug-ins.</source>
        <translation>Entferne alle Plug-Ins.</translation>
    </message>
    <message>
        <source>Use the selected plugin.</source>
        <translation type="obsolete">Benutze das ausgewählte Plug-In.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>Output progress:</source>
        <translation>Ausgabefortschritt:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <source>Wi&amp;ndows</source>
        <oldsource>&amp;Windows</oldsource>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="129"/>
        <source>H&amp;ighlighting options</source>
        <oldsource>Highlighting options</oldsource>
        <translation>Hervorhebungs-Optionen</translation>
    </message>
    <message>
        <source>You can apply system shortcuts for copy and paste.</source>
        <translation type="vanished">Sie können die System-Tastenkombinationen zum Kopieren und Einfügen verwenden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="601"/>
        <location filename="mainwindow.ui" line="737"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <source>Shows decription of a selected plug-in script.</source>
        <translation>Zeigt Beschreibung des ausgewählten Plug-In Skripts.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="616"/>
        <source>Plug-In description</source>
        <translation>Plug-In Beschreibung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="644"/>
        <source>Plug-in parameter</source>
        <oldsource>Plug-in input file</oldsource>
        <translation>Plug-In Parameter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="653"/>
        <source>Optional plug-in parameter, this may be a path to a plug-in input file</source>
        <oldsource>Optional path to a plug-in input file</oldsource>
        <translation>Optionaler Parameter, dies kann ein Pfad zu einer Eingabedatei sein</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="666"/>
        <source>Select the plug-in input file.</source>
        <translation>Wähle eine Plug-In Eingabedatei.</translation>
    </message>
    <message>
        <source>Replace spaces by nbsp entities.</source>
        <oldsource>Replace spaces by &amp;nbsp; entities.</oldsource>
        <translation type="obsolete">Ersetze Leerzeichen durch nbsp-Codes.</translation>
    </message>
    <message>
        <source>Use non breaking spaces</source>
        <translation type="obsolete">Benutze geschützte Leerzeichen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2304"/>
        <source>Do not add line numbering to lines which were automatically wrapped.</source>
        <translation>Gib bei automatisch umgebrochenen Zeilen keine Nummerierung aus.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2307"/>
        <source>Omit line numbers of wrapped lines</source>
        <translation>Keine Nummerierung bei Umbruch</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2339"/>
        <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
        <translation>Wähle oder gib den Fontnamen ein. HTML unterstützt auch eine mit Komma getrennte Liste von Fonts.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2351"/>
        <source>Font si&amp;ze:</source>
        <translation>Schrift&amp;größe:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2388"/>
        <source>&amp;Open files</source>
        <translation>Öffne &amp;Dateien</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2393"/>
        <source>&amp;Exit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2398"/>
        <source>&amp;Load</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2403"/>
        <source>&amp;Save</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2408"/>
        <source>Load &amp;default project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2413"/>
        <source>&amp;Readme</source>
        <oldsource>Readme</oldsource>
        <translation>&amp;Handbuch</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2418"/>
        <source>&amp;Tips</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2426"/>
        <source>&amp;Changelog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2431"/>
        <source>&amp;License</source>
        <translation>&amp;Lizenz</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2436"/>
        <source>&amp;About Highlight</source>
        <translation>&amp;Über Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2441"/>
        <source>A&amp;bout translations</source>
        <oldsource>About &amp;translations</oldsource>
        <translation>&amp;Infos zu Übersetzungen</translation>
    </message>
</context>
<context>
    <name>ShowTextFile</name>
    <message>
        <location filename="showtextfile.ui" line="17"/>
        <source>Show text</source>
        <translation>Textanzeige</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="37"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="71"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>io_report</name>
    <message>
        <location filename="io_report.ui" line="14"/>
        <source>Error summary</source>
        <translation>Fehlerübersicht</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="24"/>
        <source>Input errors:</source>
        <translation>Eingabefehler:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="34"/>
        <source>Remove files above from input file list</source>
        <translation>Obige Dateien aus der Eingabeliste löschen</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="48"/>
        <source>Output errors:</source>
        <translation>Ausgabefehler:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="65"/>
        <source>Reformatting not possible:</source>
        <translation>Neuformatierung nicht möglich:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="82"/>
        <source>Failed syntax tests:</source>
        <translation>Fehlgeschlagene Syntaxtests:</translation>
    </message>
</context>
<context>
    <name>syntax_chooser</name>
    <message>
        <location filename="syntax_chooser.ui" line="14"/>
        <source>Syntax selection</source>
        <translation>Syntaxauswahl</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="32"/>
        <source>Select correct syntax</source>
        <translation>Syntax bestimmen</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="50"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="74"/>
        <source>These entries are configured in filetypes.conf.</source>
        <translation>Diese Einträge werden in der filetypes.conf festgelegt.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="81"/>
        <source>The selection will be remembered for this session.</source>
        <translation>Die Auswahl wird für diese Sitzung gespeichert.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="84"/>
        <source>Remember selection</source>
        <translation>Auswahl merken</translation>
    </message>
    <message>
        <location filename="syntax_chooser.cpp" line="57"/>
        <source>The file extension %1 is assigned to multiple syntax definitions.
Select the correct one:</source>
        <translation>Die Dateiendung %1 ist mehreren Sprachdefinitionen zugeordnet.
Wähle die richtige aus:</translation>
    </message>
</context>
</TS>
